import { css } from '@tesseract-design/css-utils';
import {LayoutArgs} from '../common';

export const ContentBase = () => css.cx(
  css`
    box-sizing: border-box;
  `,
  css.media('(min-width: 1080px)')(
    css`
      padding-left: calc(50% - (var(--base-width) * 0.5));
    `
  ),
);

export const SidebarOverflow = () => css.cx(
  css`
    width: 100%;
    height: 100%;
    overflow: auto;
    // overflow: overlay;
    position: relative;
    z-index: 1;
    scrollbar-width: none;
    &::-webkit-scrollbar {
      display: none;
    }
  `
)

export const SidebarBase = ({
  mainSidebarOpen,
}: LayoutArgs) => css.cx(
  css`
    box-sizing: border-box;
	  position: fixed;
	  top: 0;
	  left: -100%;
	  width: 100%;
	  height: 100%;
    background-color: white;
    & > * {
      display: block;
		  width: 100%;
		  height: 100%;
    }
  `,
  css.media('(min-width: 1080px)')(
    css`
      width: calc(50% - (var(--base-width) * 0.5));
      left: 0;
    `
  ),
  css.if(mainSidebarOpen)(
    css`
      left: 0;
    `
  ),
);

export const SidebarMainContainer = () => css.cx(
  css`
    width: 100%;
    margin: 0 auto;
    padding: 0 1rem;
    box-sizing: border-box;
    max-width: calc(var(--base-width) * 2);
  `,
  css.media('(min-width: 1080px)')(
    css`
      width: var(--base-width);
      margin-right: 0;
    `
  ),
);

export const ContentContainer = () => css.cx(
  css`
    padding: 0 1rem;
    box-sizing: border-box;
    width: 100%;
    max-width: calc(var(--base-width) * 2);
    margin-right: auto;
    margin-left: auto;
  `,
  css.media('(min-width: 1080px)')(
    css`
      margin-left: 0;
    `
  ),
);
